using System;
using System.Linq;
using System.Collections.Generic;

class Solution {

    private static List<Vector2> buffer = new();
    private static List<Rect> obstacles = new();

  public static void Main(string[] args) {
    int[] values = Console.ReadLine().Split(" ").Select(n => int.Parse(n)).ToArray();
    Vector2 roomSize = new (values[0], values[1]);
    int rectCount = values[2];

    List<Rect> rects = new();

    for(int i = 0; i < rectCount; i++)
    {
        var r = Console.ReadLine().Split(" ").Select(n => int.Parse(n)).ToList();
        rects.Add(new Rect(new Vector2(r[0], r[1]), new Vector2(r[2], r[3])));
    }

    var result = CanReach(roomSize, rects) ? "YES" : "NO"; 
    Console.WriteLine(result);
  }

  public static bool CanReach(Vector2 dest, List<Rect> obst)
  {
    buffer = new();
    obstacles = obst;
    buffer.Add(new Vector2(0, 0));
    return ReachIteration(new Vector2(0, 0), dest);
  }

  private static bool ReachIteration(Vector2 current, Vector2 dest)
  {
    if(current == dest) return true;
    var nb = GetNeigbours(current).Where(n => IsValid(n, dest)).ToList();
    buffer.AddRange(nb);

    foreach(var n in nb)
    {
        //if(!IsValid(n, dest)) continue;
        if(buffer.Contains(n)) continue;
        if(obstacles.Any(o => IsWithinRectangle(n, o))) continue;
        
        if(ReachIteration(n, dest)) return true;
    }

    return false;
  }

  private static bool IsWithinRectangle(Vector2 point, Rect r)
  {
    return point.x >= r.TopLeft.x && point.x <= r.BottomRight.x &&
           point.y >= r.TopLeft.y && point.y <= r.BottomRight.y;
  }

  private static bool IsValid(Vector2 point, Vector2 limit)
  {
    return IsWithinRectangle(point, new Rect(new Vector2(0, 0), limit));
  }

  public static List<Vector2> GetNeigbours(Vector2 p)
  {
    List<Vector2> l = new();
    double i = 0.5;
    l.Add(new (p.x + i, p.y));
    l.Add(new (p.x - i, p.y));
    l.Add(new (p.x, p.y + i));
    l.Add(new (p.x, p.y - i));
    return l;
  }

  public struct Vector2
  {
    public double x;
    public double y;

    public Vector2(double x, double y)
    {
        this.x = x;
        this.y = y;
    }

    public static bool operator ==(Vector2 a, Vector2 b)
    {
        return a.x == b.x && a.y == b.y;
    }

    public static bool operator !=(Vector2 a, Vector2 b)
    {
        return !(a == b);
    }

    public bool Equals(object o)
    {
        if(o is not Vector2 v) return false;
        return this == v;
    }

    public int GetHasCode()
    {
        return 0;
    }
  }

  public struct Rect
  {
    public Vector2 TopLeft;
    public Vector2 BottomRight;

    public Rect(Vector2 tl, Vector2 br)
    {
        TopLeft = tl;
        BottomRight = br;
    }
  }
}
