#include <iostream>
#include <set>
#include <vector>
#include <climits>
#include <string>
#include <algorithm>
#include <cmath>
#include <map>

using namespace std;

typedef long long ll;
typedef long long ull;
typedef pair<int, int> pint;
typedef pair<ll, ll> pll;

struct rect 
{
    int left, right, top, bottom;

    rect(int l, int r, int t, int b)
    {
        left = l;
        right = r;
        top = t;
        bottom = b;
    }
};

vector<vector<int>> ways;
vector<bool> active;
int minx, maxx, miny, maxy;
vector<rect> rects;

void Init()
{
    minx = INT_MAX;
    maxx = 0;
    miny = INT_MAX;
    maxy = 0;
}

void Dive(int st)
{
    minx = min(rects[st].left, minx);
    miny = min(rects[st].bottom, miny);
    maxx = max(rects[st].right, maxx);
    maxy = max(rects[st].top, maxy);
    active[st] = false;
    for (int i = 0; i < ways[st].size(); i++)
    {
        if (active[ways[st][i]]) Dive(ways[st][i]);
    }
}

bool in_rect(int x, int y, rect* r)
{
    return (x >= r->left) && (x <= r->right) && (y >= r->bottom) && (y <= r->top);
}

bool check_intersection(rect* r1, rect* r2)
{
    return in_rect(r1->left, r1->top, r2) || in_rect(r1->right, r1->top, r2) || in_rect(r1->left, r1->bottom, r2) || in_rect(r1->right, r1->bottom, r2);
}

int main()
{
    ios::sync_with_stdio(0);
    cin.tie(0); cout.tie(0);
    int n, m, k;
    cin >> n >> m >> k;
    for (int i = 0; i < k; i++)
    {
        int l, r, t, b; 
        cin >> l >> b >> r >> t;
        rects.push_back(rect(l, r, t, b));
    }
    ways = vector<vector<int>>(k, vector<int>());
    active = vector<bool>(k, true);
    for (int i = 0; i < k; i++)
    {
        for (int j = 0; j < k; j++)
        {
            if (i == j) continue;
            if (check_intersection(&rects[i], &rects[j]) || check_intersection(&rects[j], &rects[i])) ways[i].push_back(j);
        }
    }
    bool ok = true;
    for (int i = 0; i < k; i++)
    {
        if (active[i]) 
        {
            Init();
            Dive(i);
            if ((minx == 0 && miny == 0) || (maxx == n && maxy == m) || (minx == 0 && maxx == n) || (miny == 0 && maxy == m))
            {
                ok = false;
                break;
            }
        }
    }
    if (ok) cout << "YES\n";
    else cout << "NO\n";
}