#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>

using namespace std;
using namespace __gnu_pbds;
using ll = long long;

const int N = 1e6;
ll logs[N + 1];

struct Fenwick {
    vector<ll> fen;
    vector<ll> arr;

    Fenwick(vector<ll>& a) {
        ll n = a.size();
        fen.assign(n + 1, 0);
        arr.assign(n + 1, 0);

        int i = 1;
        while (i <= n) {
            arr[i] = a[i - 1];
            fen[i] += arr[i];

            int j = i + (i & (-i));
            if (j <= n) {
                fen[j] += fen[i];
            }
        }
    }

    ll getSum(ll r) {
        int j = r;
        ll res = 0;
        while (j > 0) {
            res += fen[j];
            j -= (j & (-j));
        }
        return res;
    }

    ll query(ll l, ll r) {
        return getSum(r) - getSum(l - 1);
    }

    void update(ll i, ll val) {
        int j = i;
        while (j < fen.size()) {
            fen[j] -= arr[i];
            fen[j] += val;
            j += (j & (-j));
        }
        arr[i] = val;
    }
};

struct Segment {
    vector<ll> seg;
    vector<ll> lazy;

    Segment(vector<ll>& arr) {
        ll n = arr.size();
        seg.assign(4 * n, 0);
        lazy.assign(4 * n, 0);
        build(0, 0, n - 1, arr);
    }

    void build(ll ind, ll low, ll high, vector<ll>& arr) {
        if (low == high) {
            seg[ind] = arr[low];
        }
        else {
            int mid = (low + high) / 2;
            build(ind * 2 + 1, low, mid, arr);
            build(ind * 2 + 2, mid + 1, high, arr);
        }
    }

    ll query(ll ind, ll l, ll r, ll low, ll high) {
        if (lazy[ind] != 0) {
            seg[ind] += lazy[ind];
            if (low != high) {
                lazy[ind * 2 + 1] += lazy[ind];
                lazy[ind * 2 + 2] += lazy[ind];
            }
            lazy[ind] = 0;
        }
        if (high < l || low > r || high < low) return LLONG_MAX;
        else if (high <= r && low >= l) return seg[ind];
        else {
            int mid = (low + high) / 2;
            return min(query(ind * 2 + 1, l, r, low, mid), query(ind * 2 + 2, l, r, mid + 1, high));
        }
    }

    void update(ll ind, ll l, ll r) {

    }
};

struct Sparse {
    vector<vector<ll>> sp;

    Sparse() {

    }

    Sparse(vector<ll>& arr) {
        ll n = arr.size();
        sp.assign(n, vector<ll>(logs[n] + 1, 0));

        for (int i = 0; i < n; i++) sp[i][0] = arr[i];

        for (int p = 1; p <= logs[n]; p++) {
            for (int i = 0; i <= n - (1 << p); i++) {
                sp[i][p] = min(sp[i][p - 1], sp[i + (1 << (p - 1))][p - 1]);
            }
        }
    }

    ll query(ll l, ll r) {
        if (r < l) return LLONG_MAX;
        ll p = logs[r - l + 1];
        return min(sp[l][p], sp[r - (1 << p) + 1][p]);
    }
};

const int K = 5;
ll n, m, k;
ll rects[K][4];


map<pair<ll, ll>, bool> memo;

bool topToBottom(ll j, ll goal, ll notGoal, vector<bool>& visited) {
    if (j == -1) {
        bool ans = false;
        for (int i = 0; i < k; i++) {
            if (rects[i][2] == 0 || rects[i][1] == notGoal) {
                ans |= topToBottom(i, goal, notGoal, visited);
                if (ans) break;
            }
        }
        return memo[{j, goal}] = ans;
    }
    visited[j] = true;
    if (memo.count({j, goal})) return memo[{j, goal}];
    if (rects[j][0] == 0 || rects[j][3] == goal) {
        return memo[{j, goal}] = true;
    }
    bool ans = false;
    for (int i = 0; i < k; i++) {
        if (j == i) continue;
        if (rects[i][1] >= rects[j][0] && rects[i][0] <= rects[j][1] && rects[i][2] <= rects[j][3] && !visited[i]) {
            ans |= topToBottom(i, goal, notGoal, visited);
            if (ans) break;
        }
    }
    visited[j] = false;
    return memo[{j, goal}] = ans;
}

// bool bottomToTop(ll j, ll goal, ll notGoal, vector<bool>& visited) {
//     if (j == -1) {
//         bool ans = false;
//         for (int i = 0; i < k; i++) {
//             if (rects[i][1] == notGoal) {
//                 ans |= bottomToTop(i, goal, notGoal, visited);
//                 if (ans) break;
//             }
//         }
//         return memo[{j, goal}] = ans;
//     }
//     visited[j] = true;
//     if (memo.count({j, goal})) return memo[{j, goal}];
//     if (rects[j][3] == goal) {
//         return memo[{j, goal}] = true;
//     }
//     bool ans = false;
//     for (int i = 0; i < k; i++) {
//         if (j == i) continue;
//         if (rects[i][1] >= rects[j][0] && rects[i][0] <= rects[j][1] && rects[i][3] >= rects[j][2] && rects[i][2] <= rects[j][2] && !visited[i]) {
//             ans |= bottomToTop(i, goal, notGoal, visited);
//             if (ans) break;
//         }
//     }
//     visited[j] = false;
//     return memo[{j, goal}] = ans;
// }

int main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    
    cin >> n >> m >> k;

    for (int i = 0; i < k; i++) {
        for (int j = 0; j < 4; j++) cin >> rects[i][j];
        swap(rects[i][1], rects[i][2]); 
    }
    vector<bool> visited(k);
    bool res = false;
    for (int i = 0; i < 2; i++) {
        ll goal = i == 0 ? m : n;
        ll notGoal = i == 0 ? n : m;
        bool ok = topToBottom(-1, goal, notGoal, visited);
        if (ok) res = true;
        for (int i = 0; i < k; i++) {
            swap(rects[i][0], rects[i][2]);
            swap(rects[i][1], rects[i][3]);
        }
    }
    printf(res ? "NO\n" : "YES\n");
}